spannertools.DirectedSpanner
============================

.. abjad-lineage:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner

.. autoclass:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.append
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.append_left
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.attach
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.components
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.detach
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.direction
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.extend
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.extend_left
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.fracture
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.fuse
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.get_duration
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.get_timespan
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.index
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.leaves
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.override
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.pop
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.pop_left
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.set
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__call__
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__contains__
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__copy__
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__eq__
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__getitem__
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__len__
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__lt__
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__ne__
      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.set
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.attach
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__repr__
   :noindex:
